@@ -1,12 +1,11 @@
 # MIT licensed
 # Copyright (c) 2013-2020 lilydjwg <lilydjwg@gmail.com>, et al.
 
-from flaky import flaky
 import pytest
 pytestmark = [pytest.mark.asyncio,
               pytest.mark.needs_net]
 
-@flaky(max_runs=10)
+@pytest.mark.flaky(reruns=10)
 async def test_gitea(get_version):
     ver = await get_version("example", {
         "source": "gitea",
@@ -14,7 +13,7 @@ async def test_gitea(get_version):
     assert len(ver) == 8
     assert ver.isdigit()
 
-@flaky(max_runs=10)
+@pytest.mark.flaky(reruns=10)
 async def test_gitea_max_tag_with_include(get_version):
     assert await get_version("example", {
         "source": "gitea",
